@@ -1,4 +1,4 @@
-#       $Id: Rule.pm 1736 2003-10-22 17:03:21Z richardc $
+#       $Id: Rule.pm 1759 2003-11-10 22:07:31Z richardc $
 
 package File::Find::Rule;
 use strict;
@@ -10,7 +10,7 @@ use Carp qw/croak/;
 use File::Find (); # we're only wrapping for now
 use Cwd;           # 5.00503s File::Find goes screwy with max_depth == 0
 
-$VERSION = '0.25';
+$VERSION = '0.26';
 
 # we'd just inherit from Exporter, but I want the colon
 sub import {
@@ -248,33 +248,27 @@ L<Number::Compare> semantics.
 =cut
 
 {
-    my @tests = qw( dev ino mode nlink uid gid rdev
-                    size atime mtime ctime blksize blocks );
+    my @test_names = qw( dev ino mode nlink uid gid rdev
+                         size atime mtime ctime blksize blocks );
 
     my $i = 0;
-    for my $t (@tests) {
-        my $index = $i; # needs to be here so it can be closed over
+    for my $test (@test_names) {
+        my $index = $i++; # to close over
         my $sub = sub {
             my $self = _force_object shift;
 
-            my @tests = map { Number::Compare->new($_) } @_;
+            my @tests = map { Number::Compare->parse_to_perl($_) } @_;
 
             push @{ $self->{rules} }, {
-                rule => $t,
+                rule => $test,
                 args => \@_,
-                code => sub {
-                    my $value = (stat $_)[$index] || 0;
-                    for my $test (@tests) {
-                        return 1 if $test->($value);
-                    }
-                    return 0;
-                },
+                code => 'do { my $val = (stat $_)['.$index.'] || 0;'.
+                  join ('||', map { "(\$val $_)" } @tests ).' }',
             };
             $self;
         };
-        ++$i;
         no strict 'refs';
-        *$t = $sub;
+        *$test = $sub;
     }
 }
 
@@ -580,7 +574,7 @@ sub in {
 
     #use Data::Dumper;
     #print Dumper \@subs;
-    #print "Compiled sub: '$code'\n";
+    #warn "Compiled sub: '$code'\n";
 
     my $sub = eval "$code" or die "compile error '$code' $@";
     my $cwd = getcwd;
